#!/bin/bash
# We're executing some admin task as root (modifing perms)
CLUSTER_HOME=/var/opt/jfrog/cluster

node="art-primary"

# Set the licence key
echo -n "$ART_PRIMARY_LICENSE" > /etc/opt/jfrog/artifactory/artifactory.lic

# Checking permissions for mounted volumes
ARTIFACTORY_FOLDERS=$(mount | grep artifactory | awk '{print $3}')

function checkFolderPermissions {
    DIR=$1

    STAT=( $(stat -Lc "%A %G %U" $1) )
    PERM=${STAT[0]}
    GROUP=${STAT[1]}
    USER=${STAT[2]}

    if [[ $USER != "artifactory" ]] || [[ $GROUP != "artifactory"  ]] ; then
            if [[ ! $PERM =~ d......rw.  ]] ; then
                    echo "[WARN] artifactory user doesn't have read & write permissions on $1, adding permissions a+wr"
                    chmod a+wr $1
            fi
    elif [[ $USER == "artifactory" ]] && [[ ! $PERM =~ drw....... ]] ; then
            echo "[WARN] artifactory user doesn't have read & write permissions on $1, adding permissions u+wr"
            chmod u+wr $1
    elif [[ $GROUP == "artifactory" ]] && [[ ! $PERM =~ d...rw.... ]] ; then
            echo "[WARN] artifactory user doesn't have read & write permissions on $1, adding permissions g+wr"
            chmod g+wr $1
    fi
}

for folder in $ARTIFACTORY_FOLDERS ; do
    checkFolderPermissions $folder
done
checkFolderPermissions $CLUSTER_HOME

# Create the cluster home content the first time 
if [ ! -f $CLUSTER_HOME/ha-etc/cluster.properties ]; then
	su artifactory -c "mkdir -p $CLUSTER_HOME/{ha-etc/{UI,plugins},ha-data/{filestore,tmp},ha-backup}"
    su artifactory -c "echo security.token=$(uuidgen) >$CLUSTER_HOME/ha-etc/cluster.properties"
fi

# Copy the licensesBucket plugin into the cluster home (always do it in case of an update of the plugin in the image)
su artifactory -c "cp -f /var/opt/jfrog/artifactory/etc/plugins/licensesBucket.groovy $CLUSTER_HOME/ha-etc/plugins/licensesBucket.groovy"

# Recreate the storage.propreties if the necessary env var are set
if [ ! -z "$DATABASE_CONNECTION_STRING" ] && [ ! -z "$DATABASE_USER" ] && [ ! -z "$DATABASE_PASSWORD" ]; then
cat >$CLUSTER_HOME/ha-etc/storage.properties <<EOF
type=mysql
driver=com.mysql.jdbc.Driver
url=$DATABASE_CONNECTION_STRING
username=$DATABASE_USER
password=$DATABASE_PASSWORD
EOF
chown artifactory: $CLUSTER_HOME/ha-etc/storage.properties
fi

cat >/etc/opt/jfrog/artifactory/ha-node.properties <<EOF
node.id="art-primary"
cluster.home=$CLUSTER_HOME
primary=true
context.url=http://$(hostname -I|awk '{print $1}'):8081/artifactory
membership.port=10042
EOF
chown artifactory: /etc/opt/jfrog/artifactory/ha-node.properties


# Wait for mysql
# Extract mysql hostname and port from the jdbc url
mysql_host_port=$(echo $DATABASE_CONNECTION_STRING | sed -e 's,^jdbc:mysql:\/\/\(.*\)$,\1:,g' | cut -d/ -f1)
echo "mysql host : $mysql_host_port"
while ! curl -s "$mysql_host_port" > /dev/null; do echo 'waiting for mysql'; sleep 3; done

# Run as artifactory user
su artifactory -m /opt/jfrog/artifactory/bin/artifactory.sh
